import { BaseWidgetDirective } from '@agnos-ui/angular-headless';
import type { SlotContent } from '@agnos-ui/angular-headless';
import { TemplateRef } from '@angular/core';
import type { ProgressbarContext, ProgressbarWidget } from './progressbar.gen';
import type { BSContextualClass } from '@agnos-ui/core-bootstrap/types';
import * as i0 from "@angular/core";
/**
 * Directive that provides a template reference for the progress bar context.
 * This directive provides a template reference for the {@link ProgressbarContext}.
 */
export declare class ProgressbarBodyDirective {
    templateRef: TemplateRef<any>;
    static ngTemplateContextGuard(_dir: ProgressbarStructureDirective, context: unknown): context is ProgressbarContext;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProgressbarBodyDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ProgressbarBodyDirective, "ng-template[auProgressbarBody]", never, {}, {}, never, never, true, never>;
}
/**
 * Directive to define the structure of a progress bar.
 *
 * This directive provides a template reference for the {@link ProgressbarContext}.
 */
export declare class ProgressbarStructureDirective {
    templateRef: TemplateRef<any>;
    static ngTemplateContextGuard(_dir: ProgressbarStructureDirective, context: unknown): context is ProgressbarContext;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProgressbarStructureDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ProgressbarStructureDirective, "ng-template[auProgressbarStructure]", never, {}, {}, never, never, true, never>;
}
/**
 * Represents the default slot structure for the progress bar component.
 */
export declare const progressbarDefaultSlotStructure: SlotContent<ProgressbarContext>;
/**
 * ProgressbarComponent is a UI component that extends the BaseWidgetDirective
 * to create a customizable progress bar widget. It provides various inputs
 * to configure the appearance and behavior of the progress bar.
 *
 */
export declare class ProgressbarComponent extends BaseWidgetDirective<ProgressbarWidget> {
    /**
     * The aria label.
     *
     * @defaultValue `'Progressbar'`
     */
    ariaLabel: string | undefined;
    /**
     * The minimum value.
     *
     * @defaultValue `0`
     */
    min: number | undefined;
    /**
     * The maximum value.
     *
     * @defaultValue `100`
     */
    max: number | undefined;
    /**
     * The current value.
     *
     * @defaultValue `0`
     */
    value: number | undefined;
    /**
     * CSS classes to be applied on the widget main container
     *
     * @defaultValue `''`
     */
    className: string | undefined;
    /**
     * Label of the progress.
     */
    children: SlotContent<ProgressbarContext>;
    slotDefaultFromContent: ProgressbarBodyDirective | undefined;
    /**
     * Global template for the Progressbar.
     */
    structure: SlotContent<ProgressbarContext>;
    slotStructureFromContent: ProgressbarStructureDirective | undefined;
    /**
     * Height of the progressbar, can be any valid css height value.
     *
     * @defaultValue `''`
     */
    height: string | undefined;
    /**
     * If `true`, animates a striped progressbar.
     * Takes effect only for browsers supporting CSS3 animations, and if `striped` is `true`.
     *
     * @defaultValue `false`
     */
    animated: boolean | undefined;
    /**
     * If `true`, shows a striped progressbar.
     *
     * @defaultValue `false`
     */
    striped: boolean | undefined;
    /**
     * Return the value for the 'aria-valuetext' attribute.
     * @param value - current value
     * @param minimum - minimum value
     * @param maximum - maximum value
     *
     * @defaultValue
     * ```ts
     * () => undefined
     * ```
     */
    ariaValueTextFn: ((value: number, minimum: number, maximum: number) => string | undefined) | undefined;
    /**
     * Type of the progressbar, following bootstrap types.
     */
    type: BSContextualClass | undefined;
    slotChildren?: TemplateRef<void>;
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<ProgressbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ProgressbarComponent, "[auProgressbar]", never, { "ariaLabel": { "alias": "auAriaLabel"; "required": false; }; "min": { "alias": "auMin"; "required": false; }; "max": { "alias": "auMax"; "required": false; }; "value": { "alias": "auValue"; "required": false; }; "className": { "alias": "auClassName"; "required": false; }; "children": { "alias": "auChildren"; "required": false; }; "structure": { "alias": "auStructure"; "required": false; }; "height": { "alias": "auHeight"; "required": false; }; "animated": { "alias": "auAnimated"; "required": false; }; "striped": { "alias": "auStriped"; "required": false; }; "ariaValueTextFn": { "alias": "auAriaValueTextFn"; "required": false; }; "type": { "alias": "auType"; "required": false; }; }, {}, ["slotDefaultFromContent", "slotStructureFromContent"], ["*"], true, never>;
    static ngAcceptInputType_min: unknown;
    static ngAcceptInputType_max: unknown;
    static ngAcceptInputType_value: unknown;
    static ngAcceptInputType_animated: unknown;
    static ngAcceptInputType_striped: unknown;
}
